@@ -1,6 +1,6 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
    | Copyright (c) 1997-2015 The PHP Group                                |
    +----------------------------------------------------------------------+
@@ -40,12 +40,14 @@ PHP_FUNCTION(header)
 {
 	zend_bool rep = 1;
 	sapi_header_line ctr = {0};
+	size_t len;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|bl", &ctr.line,
-				&ctr.line_len, &rep, &ctr.response_code) == FAILURE)
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|bl", &ctr.line,
+				&len, &rep, &ctr.response_code) == FAILURE)
 		return;
 
-	sapi_header_op(rep ? SAPI_HEADER_REPLACE:SAPI_HEADER_ADD, &ctr TSRMLS_CC);
+	ctr.line_len = (uint)len;
+	sapi_header_op(rep ? SAPI_HEADER_REPLACE:SAPI_HEADER_ADD, &ctr);
 }
 /* }}} */
 
@@ -54,18 +56,20 @@ PHP_FUNCTION(header)
 PHP_FUNCTION(header_remove)
 {
 	sapi_header_line ctr = {0};
+	size_t len = 0;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|s", &ctr.line,
-	                          &ctr.line_len) == FAILURE)
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "|s", &ctr.line,
+	                          &len) == FAILURE)
 		return;
 
-	sapi_header_op(ZEND_NUM_ARGS() == 0 ? SAPI_HEADER_DELETE_ALL : SAPI_HEADER_DELETE, &ctr TSRMLS_CC);
+	ctr.line_len = (uint)len;
+	sapi_header_op(ZEND_NUM_ARGS() == 0 ? SAPI_HEADER_DELETE_ALL : SAPI_HEADER_DELETE, &ctr);
 }
 /* }}} */
 
-PHPAPI int php_header(TSRMLS_D)
+PHPAPI int php_header(void)
 {
-	if (sapi_send_headers(TSRMLS_C)==FAILURE || SG(request_info).headers_only) {
+	if (sapi_send_headers()==FAILURE || SG(request_info).headers_only) {
 		return 0; /* don't allow output */
 	} else {
 		return 1; /* allow output */
@@ -73,100 +77,106 @@ PHPAPI int php_header(TSRMLS_D)
 }
 
 
-PHPAPI int php_setcookie(char *name, int name_len, char *value, int value_len, time_t expires, char *path, int path_len, char *domain, int domain_len, int secure, int url_encode, int httponly TSRMLS_DC)
+PHPAPI int php_setcookie(zend_string *name, zend_string *value, time_t expires, zend_string *path, zend_string *domain, int secure, int url_encode, int httponly)
 {
-	char *cookie, *encoded_value = NULL;
-	int len=sizeof("Set-Cookie: ");
-	char *dt;
+	char *cookie;
+	size_t len = sizeof("Set-Cookie: ");
+	zend_string *dt;
 	sapi_header_line ctr = {0};
 	int result;
+	zend_string *encoded_value = NULL;
 
-	if (name && strpbrk(name, "=,; \t\r\n\013\014") != NULL) {   /* man isspace for \013 and \014 */
-		zend_error( E_WARNING, "Cookie names cannot contain any of the following '=,; \\t\\r\\n\\013\\014'" );
+	if (!ZSTR_LEN(name)) {
+		zend_error( E_WARNING, "Cookie names must not be empty" );
+		return FAILURE;
+	} else if (strpbrk(ZSTR_VAL(name), "=,; \t\r\n\013\014") != NULL) {   /* man isspace for \013 and \014 */
+		zend_error(E_WARNING, "Cookie names cannot contain any of the following '=,; \\t\\r\\n\\013\\014'" );
 		return FAILURE;
 	}
 
-	if (!url_encode && value && strpbrk(value, ",; \t\r\n\013\014") != NULL) { /* man isspace for \013 and \014 */
-		zend_error( E_WARNING, "Cookie values cannot contain any of the following ',; \\t\\r\\n\\013\\014'" );
+	if (!url_encode && value &&
+			strpbrk(ZSTR_VAL(value), ",; \t\r\n\013\014") != NULL) { /* man isspace for \013 and \014 */
+		zend_error(E_WARNING, "Cookie values cannot contain any of the following ',; \\t\\r\\n\\013\\014'" );
 		return FAILURE;
 	}
 
-	len += name_len;
-	if (value && url_encode) {
-		int encoded_value_len;
-
-		encoded_value = php_url_encode(value, value_len, &encoded_value_len);
-		len += encoded_value_len;
-	} else if ( value ) {
-		encoded_value = estrdup(value);
-		len += value_len;
+	len += ZSTR_LEN(name);
+	if (value) {
+		if (url_encode) {
+			encoded_value = php_url_encode(ZSTR_VAL(value), ZSTR_LEN(value));
+			len += ZSTR_LEN(encoded_value);
+		} else {
+			encoded_value = zend_string_copy(value);
+			len += ZSTR_LEN(encoded_value);
+		}
 	}
+
 	if (path) {
-		len += path_len;
+		len += ZSTR_LEN(path);
 	}
 	if (domain) {
-		len += domain_len;
+		len += ZSTR_LEN(domain);
 	}
 
 	cookie = emalloc(len + 100);
 
-	if (value == NULL || value_len == 0) {
+	if (value == NULL || ZSTR_LEN(value) == 0) {
 		/*
 		 * MSIE doesn't delete a cookie when you set it to a null value
 		 * so in order to force cookies to be deleted, even on MSIE, we
 		 * pick an expiry date in the past
 		 */
-		dt = php_format_date("D, d-M-Y H:i:s T", sizeof("D, d-M-Y H:i:s T")-1, 1, 0 TSRMLS_CC);
-		snprintf(cookie, len + 100, "Set-Cookie: %s=deleted; expires=%s; Max-Age=0", name, dt);
-		efree(dt);
+		dt = php_format_date("D, d-M-Y H:i:s T", sizeof("D, d-M-Y H:i:s T")-1, 1, 0);
+		snprintf(cookie, len + 100, "Set-Cookie: %s=deleted; expires=%s; Max-Age=0", ZSTR_VAL(name), ZSTR_VAL(dt));
+		zend_string_free(dt);
 	} else {
-		snprintf(cookie, len + 100, "Set-Cookie: %s=%s", name, value ? encoded_value : "");
+		snprintf(cookie, len + 100, "Set-Cookie: %s=%s", ZSTR_VAL(name), value ? ZSTR_VAL(encoded_value) : "");
 		if (expires > 0) {
 			const char *p;
 			char tsdelta[13];
-			strlcat(cookie, "; expires=", len + 100);
-			dt = php_format_date("D, d-M-Y H:i:s T", sizeof("D, d-M-Y H:i:s T")-1, expires, 0 TSRMLS_CC);
+			strlcat(cookie, COOKIE_EXPIRES, len + 100);
+			dt = php_format_date("D, d-M-Y H:i:s T", sizeof("D, d-M-Y H:i:s T")-1, expires, 0);
 			/* check to make sure that the year does not exceed 4 digits in length */
-			p = zend_memrchr(dt, '-', strlen(dt));
+			p = zend_memrchr(ZSTR_VAL(dt), '-', ZSTR_LEN(dt));
 			if (!p || *(p + 5) != ' ') {
-				efree(dt);
+				zend_string_free(dt);
 				efree(cookie);
-				efree(encoded_value);
+				zend_string_release(encoded_value);
 				zend_error(E_WARNING, "Expiry date cannot have a year greater than 9999");
 				return FAILURE;
 			}
-			strlcat(cookie, dt, len + 100);
-			efree(dt);
+			strlcat(cookie, ZSTR_VAL(dt), len + 100);
+			zend_string_free(dt);
 
-			snprintf(tsdelta, sizeof(tsdelta), "%li", (long) difftime(expires, time(NULL)));
-			strlcat(cookie, "; Max-Age=", len + 100);
+			snprintf(tsdelta, sizeof(tsdelta), ZEND_LONG_FMT, (zend_long) difftime(expires, time(NULL)));
+			strlcat(cookie, COOKIE_MAX_AGE, len + 100);
 			strlcat(cookie, tsdelta, len + 100);
 		}
 	}
 
 	if (encoded_value) {
-		efree(encoded_value);
+		zend_string_release(encoded_value);
 	}
 
-	if (path && path_len > 0) {
-		strlcat(cookie, "; path=", len + 100);
-		strlcat(cookie, path, len + 100);
+	if (path && ZSTR_LEN(path)) {
+		strlcat(cookie, COOKIE_PATH, len + 100);
+		strlcat(cookie, ZSTR_VAL(path), len + 100);
 	}
-	if (domain && domain_len > 0) {
-		strlcat(cookie, "; domain=", len + 100);
-		strlcat(cookie, domain, len + 100);
+	if (domain && ZSTR_LEN(domain)) {
+		strlcat(cookie, COOKIE_DOMAIN, len + 100);
+		strlcat(cookie, ZSTR_VAL(domain), len + 100);
 	}
 	if (secure) {
-		strlcat(cookie, "; secure", len + 100);
+		strlcat(cookie, COOKIE_SECURE, len + 100);
 	}
 	if (httponly) {
-		strlcat(cookie, "; httponly", len + 100);
+		strlcat(cookie, COOKIE_HTTPONLY, len + 100);
 	}
 
 	ctr.line = cookie;
-	ctr.line_len = strlen(cookie);
+	ctr.line_len = (uint)strlen(cookie);
 
-	result = sapi_header_op(SAPI_HEADER_ADD, &ctr TSRMLS_CC);
+	result = sapi_header_op(SAPI_HEADER_ADD, &ctr);
 	efree(cookie);
 	return result;
 }
@@ -177,18 +187,16 @@ PHPAPI int php_setcookie(char *name, int name_len, char *value, int value_len, t
    Send a cookie */
 PHP_FUNCTION(setcookie)
 {
-	char *name, *value = NULL, *path = NULL, *domain = NULL;
-	long expires = 0;
+	zend_string *name, *value = NULL, *path = NULL, *domain = NULL;
+	zend_long expires = 0;
 	zend_bool secure = 0, httponly = 0;
-	int name_len, value_len = 0, path_len = 0, domain_len = 0;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|slssbb", &name,
-							  &name_len, &value, &value_len, &expires, &path,
-							  &path_len, &domain, &domain_len, &secure, &httponly) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "S|SlSSbb",
+				&name, &value, &expires, &path, &domain, &secure, &httponly) == FAILURE) {
 		return;
 	}
 
-	if (php_setcookie(name, name_len, value, value_len, expires, path, path_len, domain, domain_len, secure, 1, httponly TSRMLS_CC) == SUCCESS) {
+	if (php_setcookie(name, value, expires, path, domain, secure, 1, httponly) == SUCCESS) {
 		RETVAL_TRUE;
 	} else {
 		RETVAL_FALSE;
@@ -200,18 +208,16 @@ PHP_FUNCTION(setcookie)
    Send a cookie with no url encoding of the value */
 PHP_FUNCTION(setrawcookie)
 {
-	char *name, *value = NULL, *path = NULL, *domain = NULL;
-	long expires = 0;
+	zend_string *name, *value = NULL, *path = NULL, *domain = NULL;
+	zend_long expires = 0;
 	zend_bool secure = 0, httponly = 0;
-	int name_len, value_len = 0, path_len = 0, domain_len = 0;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|slssbb", &name,
-							  &name_len, &value, &value_len, &expires, &path,
-							  &path_len, &domain, &domain_len, &secure, &httponly) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "S|SlSSbb",
+				&name, &value, &expires, &path, &domain, &secure, &httponly) == FAILURE) {
 		return;
 	}
 
-	if (php_setcookie(name, name_len, value, value_len, expires, path, path_len, domain, domain_len, secure, 0, httponly TSRMLS_CC) == SUCCESS) {
+	if (php_setcookie(name, value, expires, path, domain, secure, 0, httponly) == SUCCESS) {
 		RETVAL_TRUE;
 	} else {
 		RETVAL_FALSE;
@@ -228,12 +234,12 @@ PHP_FUNCTION(headers_sent)
 	const char *file="";
 	int line=0;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|zz", &arg1, &arg2) == FAILURE)
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "|z/z/", &arg1, &arg2) == FAILURE)
 		return;
 
 	if (SG(headers_sent)) {
-		line = php_output_get_start_lineno(TSRMLS_C);
-		file = php_output_get_start_filename(TSRMLS_C);
+		line = php_output_get_start_lineno();
+		file = php_output_get_start_filename();
 	}
 
 	switch(ZEND_NUM_ARGS()) {
@@ -243,9 +249,9 @@ PHP_FUNCTION(headers_sent)
 	case 1:
 		zval_dtor(arg1);
 		if (file) {
-			ZVAL_STRING(arg1, file, 1);
+			ZVAL_STRING(arg1, file);
 		} else {
-			ZVAL_STRING(arg1, "", 1);
+			ZVAL_EMPTY_STRING(arg1);
 		}
 		break;
 	}
@@ -260,12 +266,12 @@ PHP_FUNCTION(headers_sent)
 
 /* {{{ php_head_apply_header_list_to_hash
    Turn an llist of sapi_header_struct headers into a numerically indexed zval hash */
-static void php_head_apply_header_list_to_hash(void *data, void *arg TSRMLS_DC)
+static void php_head_apply_header_list_to_hash(void *data, void *arg)
 {
 	sapi_header_struct *sapi_header = (sapi_header_struct *)data;
 
 	if (arg && sapi_header) {
-		add_next_index_string((zval *)arg, (char *)(sapi_header->header), 1);
+		add_next_index_string((zval *)arg, (char *)(sapi_header->header));
 	}
 }
 
@@ -278,7 +284,7 @@ PHP_FUNCTION(headers_list)
 	}
 
 	array_init(return_value);
-	zend_llist_apply_with_argument(&SG(sapi_headers).headers, php_head_apply_header_list_to_hash, return_value TSRMLS_CC);
+	zend_llist_apply_with_argument(&SG(sapi_headers).headers, php_head_apply_header_list_to_hash, return_value);
 }
 /* }}} */
 
@@ -286,18 +292,18 @@ PHP_FUNCTION(headers_list)
    Sets a response code, or returns the current HTTP response code */
 PHP_FUNCTION(http_response_code)
 {
-	long response_code = 0;
+	zend_long response_code = 0;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|l", &response_code) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "|l", &response_code) == FAILURE) {
 		return;
 	}
 
 	if (response_code)
 	{
-		long old_response_code;
+		zend_long old_response_code;
 
 		old_response_code = SG(sapi_headers).http_response_code;
-		SG(sapi_headers).http_response_code = response_code;
+		SG(sapi_headers).http_response_code = (int)response_code;
 
 		if (old_response_code) {
 			RETURN_LONG(old_response_code);
