@@ -1,8 +1,8 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
+   | PHP Version 7                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2016 The PHP Group                                |
+   | Copyright (c) 1997-2015 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -105,7 +105,7 @@ const zend_function_entry php_xsl_xsltprocessor_class_functions[] = {
 
 /* {{{ php_xsl_xslt_string_to_xpathexpr()
    Translates a string to a XPath Expression */
-static char *php_xsl_xslt_string_to_xpathexpr(const char *str TSRMLS_DC)
+static char *php_xsl_xslt_string_to_xpathexpr(const char *str)
 {
 	const xmlChar *string = (const xmlChar *)str;
 
@@ -116,14 +116,14 @@ static char *php_xsl_xslt_string_to_xpathexpr(const char *str TSRMLS_DC)
 
 	if (xmlStrchr(string, '"')) {
 		if (xmlStrchr(string, '\'')) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Cannot create XPath expression (string contains both quote and double-quotes)");
+			php_error_docref(NULL, E_WARNING, "Cannot create XPath expression (string contains both quote and double-quotes)");
 			return NULL;
 		}
 		value = (xmlChar*) safe_emalloc (str_len, sizeof(xmlChar), 0);
-		snprintf(value, str_len, "'%s'", string);
+		snprintf((char*)value, str_len, "'%s'", string);
 	} else {
 		value = (xmlChar*) safe_emalloc (str_len, sizeof(xmlChar), 0);
-		snprintf(value, str_len, "\"%s\"", string);
+		snprintf((char *)value, str_len, "\"%s\"", string);
 	}
 	return (char *) value;
 }
@@ -131,13 +131,14 @@ static char *php_xsl_xslt_string_to_xpathexpr(const char *str TSRMLS_DC)
 
 /* {{{ php_xsl_xslt_make_params()
    Translates a PHP array to a libxslt parameters array */
-static char **php_xsl_xslt_make_params(HashTable *parht, int xpath_params TSRMLS_DC)
+static char **php_xsl_xslt_make_params(HashTable *parht, int xpath_params)
 {
 
 	int parsize;
-	zval **value;
-	char *xpath_expr, *string_key = NULL;
-	ulong num_key;
+	zval *value;
+	char *xpath_expr;
+	zend_string *string_key;
+	zend_ulong num_key;
 	char **params = NULL;
 	int i = 0;
 
@@ -145,33 +146,27 @@ static char **php_xsl_xslt_make_params(HashTable *parht, int xpath_params TSRMLS
 	params = (char **)safe_emalloc((2 * zend_hash_num_elements(parht) + 1), sizeof(char *), 0);
 	memset((char *)params, 0, parsize);
 
-	for (zend_hash_internal_pointer_reset(parht);
-		zend_hash_get_current_data(parht, (void **)&value) == SUCCESS;
-		zend_hash_move_forward(parht)) {
-
-		if (zend_hash_get_current_key(parht, &string_key, &num_key, 1) != HASH_KEY_IS_STRING) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid argument or parameter array");
+	ZEND_HASH_FOREACH_KEY_VAL(parht, num_key, string_key, value) {
+		if (string_key == NULL) {
+			php_error_docref(NULL, E_WARNING, "Invalid argument or parameter array");
 			efree(params);
 			return NULL;
 		} else {
-			if (Z_TYPE_PP(value) != IS_STRING) {
-				SEPARATE_ZVAL(value);
-				convert_to_string(*value);
+			if (Z_TYPE_P(value) != IS_STRING) {
+				convert_to_string(value);
 			}
 
 			if (!xpath_params) {
-				xpath_expr = php_xsl_xslt_string_to_xpathexpr(Z_STRVAL_PP(value) TSRMLS_CC);
+				xpath_expr = php_xsl_xslt_string_to_xpathexpr(Z_STRVAL_P(value));
 			} else {
-				xpath_expr = estrndup(Z_STRVAL_PP(value), Z_STRLEN_PP(value));
+				xpath_expr = estrndup(Z_STRVAL_P(value), Z_STRLEN_P(value));
 			}
 			if (xpath_expr) {
-				params[i++] = string_key;
+				params[i++] = estrndup(ZSTR_VAL(string_key), ZSTR_LEN(string_key));
 				params[i++] = xpath_expr;
-			} else {
-				efree(string_key);
 			}
 		}
-	}
+	} ZEND_HASH_FOREACH_END();
 
 	params[i++] = NULL;
 
@@ -182,20 +177,19 @@ static char **php_xsl_xslt_make_params(HashTable *parht, int xpath_params TSRMLS
 static void xsl_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs, int type) /* {{{ */
 {
 	xsltTransformContextPtr tctxt;
-	zval **args;
-	zval *retval;
-	int result, i, ret;
+	zval *args;
+	zval retval;
+	int result, i;
 	int error = 0;
 	zend_fcall_info fci;
 	zval handler;
 	xmlXPathObjectPtr obj;
 	char *str;
-	char *callable = NULL;
 	xsl_object *intern;
+	zend_string *callable = NULL;
 
-	TSRMLS_FETCH();
 
-	if (! zend_is_executing(TSRMLS_C)) {
+	if (! zend_is_executing()) {
 		xsltGenericError(xsltGenericErrorContext,
 		"xsltExtFunctionTest: Function called from outside of PHP\n");
 		error = 1;
@@ -206,7 +200,7 @@ static void xsl_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs, int t
 			"xsltExtFunctionTest: failed to get the transformation context\n");
 			error = 1;
 		} else {
-			intern = (xsl_object *) tctxt->_private;
+			intern = (xsl_object*)tctxt->_private;
 			if (intern == NULL) {
 				xsltGenericError(xsltGenericErrorContext,
 				"xsltExtFunctionTest: failed to get the internal object\n");
@@ -232,41 +226,34 @@ static void xsl_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs, int t
 
 	fci.param_count = nargs - 1;
 	if (fci.param_count > 0) {
-		fci.params = safe_emalloc(fci.param_count, sizeof(zval**), 0);
-		args = safe_emalloc(fci.param_count, sizeof(zval *), 0);
+		args = safe_emalloc(fci.param_count, sizeof(zval), 0);
 	}
 	/* Reverse order to pop values off ctxt stack */
 	for (i = nargs - 2; i >= 0; i--) {
 		obj = valuePop(ctxt);
-		MAKE_STD_ZVAL(args[i]);
-		if (obj == NULL) {
-			ZVAL_NULL(args[i]);
-			continue;
-		}
 		switch (obj->type) {
 			case XPATH_STRING:
-				ZVAL_STRING(args[i],  obj->stringval, 1);
+				ZVAL_STRING(&args[i], (char *)obj->stringval);
 				break;
 			case XPATH_BOOLEAN:
-				ZVAL_BOOL(args[i],  obj->boolval);
+				ZVAL_BOOL(&args[i],  obj->boolval);
 				break;
 			case XPATH_NUMBER:
-				ZVAL_DOUBLE(args[i], obj->floatval);
+				ZVAL_DOUBLE(&args[i], obj->floatval);
 				break;
 			case XPATH_NODESET:
 				if (type == 1) {
-					str = xmlXPathCastToString(obj);
-					ZVAL_STRING(args[i], str, 1);
+					str = (char*)xmlXPathCastToString(obj);
+					ZVAL_STRING(&args[i], str);
 					xmlFree(str);
 				} else if (type == 2) {
 					int j;
 					dom_object *domintern = (dom_object *)intern->doc;
-					array_init(args[i]);
+					array_init(&args[i]);
 					if (obj->nodesetval && obj->nodesetval->nodeNr > 0) {
 						for (j = 0; j < obj->nodesetval->nodeNr; j++) {
 							xmlNodePtr node = obj->nodesetval->nodeTab[j];
-							zval *child;
-							MAKE_STD_ZVAL(child);
+							zval child;
 							/* not sure, if we need this... it's copied from xpath.c */
 							if (node->type == XML_NAMESPACE_DECL) {
 								xmlNsPtr curns;
@@ -275,12 +262,12 @@ static void xsl_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs, int t
 								nsparent = node->_private;
 								curns = xmlNewNs(NULL, node->name, NULL);
 								if (node->children) {
-									curns->prefix = xmlStrdup((char *) node->children);
+									curns->prefix = xmlStrdup((char *)node->children);
 								}
 								if (node->children) {
 									node = xmlNewDocNode(node->doc, NULL, (char *) node->children, node->name);
 								} else {
-									node = xmlNewDocNode(node->doc, NULL, "xmlns", node->name);
+									node = xmlNewDocNode(node->doc, NULL, (const xmlChar *) "xmlns", node->name);
 								}
 								node->type = XML_NAMESPACE_DECL;
 								node->parent = nsparent;
@@ -289,99 +276,99 @@ static void xsl_ext_function_php(xmlXPathParserContextPtr ctxt, int nargs, int t
 								node = xmlDocCopyNodeList(domintern->document->ptr, node);
 							}
 
-							child = php_dom_create_object(node, &ret, child, domintern TSRMLS_CC);
-							add_next_index_zval(args[i], child);
+							php_dom_create_object(node, &child, domintern);
+							add_next_index_zval(&args[i], &child);
 						}
 					}
 				}
 				break;
 			default:
-				str = xmlXPathCastToString(obj);
-				ZVAL_STRING(args[i], str, 1);
+				str = (char *) xmlXPathCastToString(obj);
+				ZVAL_STRING(&args[i], str);
 				xmlFree(str);
 		}
 		xmlXPathFreeObject(obj);
-		fci.params[i] = &args[i];
 	}
 
 	fci.size = sizeof(fci);
 	fci.function_table = EG(function_table);
+	if (fci.param_count > 0) {
+		fci.params = args;
+	} else {
+		fci.params = NULL;
+	}
+
 
 	obj = valuePop(ctxt);
-	if (obj == NULL || obj->stringval == NULL) {
-		if (obj) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Handler name must be a string");
-			xmlXPathFreeObject(obj);
-		}
-		valuePush(ctxt, xmlXPathNewString(""));
+	if (obj->stringval == NULL) {
+		php_error_docref(NULL, E_WARNING, "Handler name must be a string");
+		xmlXPathFreeObject(obj);
+		valuePush(ctxt, xmlXPathNewString((const xmlChar *) ""));
 		if (fci.param_count > 0) {
 			for (i = 0; i < nargs - 1; i++) {
 				zval_ptr_dtor(&args[i]);
 			}
 			efree(args);
-			efree(fci.params);
 		}
 		return;
 	}
-	INIT_PZVAL(&handler);
-	ZVAL_STRING(&handler, obj->stringval, 1);
+	ZVAL_STRING(&handler, (char *) obj->stringval);
 	xmlXPathFreeObject(obj);
 
-	fci.function_name = &handler;
+	ZVAL_COPY_VALUE(&fci.function_name, &handler);
 	fci.symbol_table = NULL;
-	fci.object_ptr = NULL;
-	fci.retval_ptr_ptr = &retval;
+	fci.object = NULL;
+	fci.retval = &retval;
 	fci.no_separation = 0;
 	/*fci.function_handler_cache = &function_ptr;*/
-	if (!zend_make_callable(&handler, &callable TSRMLS_CC)) {
-		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unable to call handler %s()", callable);
-		valuePush(ctxt, xmlXPathNewString(""));
-	} else if ( intern->registerPhpFunctions == 2 && zend_hash_exists(intern->registered_phpfunctions, callable, strlen(callable) + 1) == 0) {
-		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Not allowed to call handler '%s()'", callable);
+	if (!zend_make_callable(&handler, &callable)) {
+		php_error_docref(NULL, E_WARNING, "Unable to call handler %s()", ZSTR_VAL(callable));
+		valuePush(ctxt, xmlXPathNewString((const xmlChar *) ""));
+	} else if ( intern->registerPhpFunctions == 2 && zend_hash_exists(intern->registered_phpfunctions, callable) == 0) {
+		php_error_docref(NULL, E_WARNING, "Not allowed to call handler '%s()'", ZSTR_VAL(callable));
 		/* Push an empty string, so that we at least have an xslt result... */
-		valuePush(ctxt, xmlXPathNewString(""));
+		valuePush(ctxt, xmlXPathNewString((const xmlChar *) ""));
 	} else {
-		result = zend_call_function(&fci, NULL TSRMLS_CC);
+		result = zend_call_function(&fci, NULL);
 		if (result == FAILURE) {
 			if (Z_TYPE(handler) == IS_STRING) {
-				php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unable to call handler %s()", Z_STRVAL_P(&handler));
-				valuePush(ctxt, xmlXPathNewString(""));
+				php_error_docref(NULL, E_WARNING, "Unable to call handler %s()", Z_STRVAL(handler));
+				valuePush(ctxt, xmlXPathNewString((const xmlChar *) ""));
 			}
 		/* retval is == NULL, when an exception occurred, don't report anything, because PHP itself will handle that */
-		} else if (retval == NULL) {
+		} else if (Z_ISUNDEF(retval)) {
 		} else {
-			if (retval->type == IS_OBJECT && instanceof_function( Z_OBJCE_P(retval), dom_node_class_entry TSRMLS_CC)) {
+			if (Z_TYPE(retval) == IS_OBJECT && instanceof_function(Z_OBJCE(retval), dom_node_class_entry)) {
 				xmlNode *nodep;
 				dom_object *obj;
 				if (intern->node_list == NULL) {
 					ALLOC_HASHTABLE(intern->node_list);
 					zend_hash_init(intern->node_list, 0, NULL, ZVAL_PTR_DTOR, 0);
 				}
-				zval_add_ref(&retval);
-				zend_hash_next_index_insert(intern->node_list, &retval, sizeof(zval *), NULL);
-				obj = (dom_object *)zend_object_store_get_object(retval TSRMLS_CC);
+				Z_ADDREF(retval);
+				zend_hash_next_index_insert(intern->node_list, &retval);
+				obj = Z_DOMOBJ_P(&retval);
 				nodep = dom_object_get_node(obj);
 				valuePush(ctxt, xmlXPathNewNodeSet(nodep));
-			} else if (retval->type == IS_BOOL) {
-				valuePush(ctxt, xmlXPathNewBoolean(retval->value.lval));
-			} else if (retval->type == IS_OBJECT) {
-				php_error_docref(NULL TSRMLS_CC, E_WARNING, "A PHP Object cannot be converted to a XPath-string");
-				valuePush(ctxt, xmlXPathNewString(""));
+			} else if (Z_TYPE(retval) == IS_TRUE || Z_TYPE(retval) == IS_FALSE) {
+				valuePush(ctxt, xmlXPathNewBoolean(Z_TYPE(retval) == IS_TRUE));
+			} else if (Z_TYPE(retval) == IS_OBJECT) {
+				php_error_docref(NULL, E_WARNING, "A PHP Object cannot be converted to a XPath-string");
+				valuePush(ctxt, xmlXPathNewString((const xmlChar *) ""));
 			} else {
 				convert_to_string_ex(&retval);
-				valuePush(ctxt, xmlXPathNewString( Z_STRVAL_P(retval)));
+				valuePush(ctxt, xmlXPathNewString((xmlChar *) Z_STRVAL(retval)));
 			}
 			zval_ptr_dtor(&retval);
 		}
 	}
-	efree(callable);
-	zval_dtor(&handler);
+	zend_string_release(callable);
+	zval_ptr_dtor(&handler);
 	if (fci.param_count > 0) {
 		for (i = 0; i < nargs - 1; i++) {
 			zval_ptr_dtor(&args[i]);
 		}
 		efree(args);
-		efree(fci.params);
 	}
 }
 /* }}} */
@@ -398,7 +385,7 @@ void xsl_ext_function_object_php(xmlXPathParserContextPtr ctxt, int nargs) /* {{
 }
 /* }}} */
 
-/* {{{ proto void xsl_xsltprocessor_import_stylesheet(domdocument doc);
+/* {{{ proto void xsl_xsltprocessor_import_stylesheet(domdocument doc)
 URL: http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030226/DOM3-Core.html#
 Since:
 */
@@ -411,13 +398,13 @@ PHP_FUNCTION(xsl_xsltprocessor_import_stylesheet)
 	int prevSubstValue, prevExtDtdValue, clone_docu = 0;
 	xmlNode *nodep = NULL;
 	zend_object_handlers *std_hnd;
-	zval *cloneDocu, *member;
+	zval *cloneDocu, member, rv;
 
-	if (zend_parse_method_parameters(ZEND_NUM_ARGS() TSRMLS_CC, getThis(), "Oo", &id, xsl_xsltprocessor_class_entry, &docp) == FAILURE) {
+	if (zend_parse_method_parameters(ZEND_NUM_ARGS(), getThis(), "Oo", &id, xsl_xsltprocessor_class_entry, &docp) == FAILURE) {
 		RETURN_FALSE;
 	}
 
-	nodep = php_libxml_import_node(docp TSRMLS_CC);
+	nodep = php_libxml_import_node(docp);
 
 	if (nodep) {
 		doc = nodep->doc;
@@ -444,23 +431,22 @@ PHP_FUNCTION(xsl_xsltprocessor_import_stylesheet)
 		RETURN_FALSE;
 	}
 
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	intern = Z_XSL_P(id);
 
 	std_hnd = zend_get_std_object_handlers();
-	MAKE_STD_ZVAL(member);
-	ZVAL_STRING(member, "cloneDocument", 0);
-	cloneDocu = std_hnd->read_property(id, member, BP_VAR_IS, NULL TSRMLS_CC);
+	ZVAL_STRING(&member, "cloneDocument");
+	cloneDocu = std_hnd->read_property(id, &member, BP_VAR_IS, NULL, &rv);
 	if (Z_TYPE_P(cloneDocu) != IS_NULL) {
 		convert_to_long(cloneDocu);
 		clone_docu = Z_LVAL_P(cloneDocu);
 	}
-	efree(member);
+	zval_ptr_dtor(&member);
 	if (clone_docu == 0) {
 		/* check if the stylesheet is using xsl:key, if yes, we have to clone the document _always_ before a transformation */
 		nodep = xmlDocGetRootElement(sheetp->doc);
 		if (nodep && (nodep = nodep->children)) {
 			while (nodep) {
-				if (nodep->type == XML_ELEMENT_NODE && xmlStrEqual(nodep->name, "key") && xmlStrEqual(nodep->ns->href, XSLT_NAMESPACE)) {
+				if (nodep->type == XML_ELEMENT_NODE && xmlStrEqual(nodep->name, (const xmlChar *) "key") && xmlStrEqual(nodep->ns->href, XSLT_NAMESPACE)) {
 					intern->hasKeys = 1;
 					break;
 				}
@@ -480,12 +466,12 @@ PHP_FUNCTION(xsl_xsltprocessor_import_stylesheet)
 		intern->ptr = NULL;
 	}
 
-	php_xsl_set_object(id, sheetp TSRMLS_CC);
+	php_xsl_set_object(id, sheetp);
 	RETVAL_TRUE;
 }
 /* }}} end xsl_xsltprocessor_import_stylesheet */
 
-static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStylesheetPtr style, zval *docp TSRMLS_DC) /* {{{ */
+static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStylesheetPtr style, zval *docp) /* {{{ */
 {
 	xmlDocPtr newdocp = NULL;
 	xmlDocPtr doc = NULL;
@@ -494,30 +480,30 @@ static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStyl
 	php_libxml_node_object *object;
 	char **params = NULL;
 	int clone;
-	zval *doXInclude, *member;
+	zval *doXInclude, member, rv;
 	zend_object_handlers *std_hnd;
 	FILE *f;
 	int secPrefsError = 0;
-	int secPrefsValue, secPrefsIni;
+	int secPrefsValue;
 	xsltSecurityPrefsPtr secPrefs = NULL;
 
-	node = php_libxml_import_node(docp TSRMLS_CC);
+	node = php_libxml_import_node(docp);
 
 	if (node) {
 		doc = node->doc;
 	}
 	if (doc == NULL) {
-		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid Document");
+		php_error_docref(NULL, E_WARNING, "Invalid Document");
 		return NULL;
 	}
 
 	if (style == NULL) {
-		php_error_docref(NULL TSRMLS_CC, E_WARNING, "No stylesheet associated to this object");
+		php_error_docref(NULL, E_WARNING, "No stylesheet associated to this object");
 		return NULL;
 	}
 
 	if (intern->profiling) {
-		if (php_check_open_basedir(intern->profiling TSRMLS_CC)) {
+		if (php_check_open_basedir(intern->profiling)) {
 			f = NULL;
 		} else {
 			f = VCWD_FOPEN(intern->profiling, "w");
@@ -527,7 +513,7 @@ static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStyl
 	}
 
 	if (intern->parameter) {
-		params = php_xsl_xslt_make_params(intern->parameter, 0 TSRMLS_CC);
+		params = php_xsl_xslt_make_params(intern->parameter, 0);
 	}
 
 	intern->doc = emalloc(sizeof(php_libxml_node_object));
@@ -536,45 +522,27 @@ static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStyl
 	if (intern->hasKeys == 1) {
 		doc = xmlCopyDoc(doc, 1);
 	} else {
-		object = (php_libxml_node_object *)zend_object_store_get_object(docp TSRMLS_CC);
+		object = Z_LIBXML_NODE_P(docp);
 		intern->doc->document = object->document;
 	}
 
-	php_libxml_increment_doc_ref(intern->doc, doc TSRMLS_CC);
+	php_libxml_increment_doc_ref(intern->doc, doc);
 
 	ctxt = xsltNewTransformContext(style, doc);
 	ctxt->_private = (void *) intern;
 
 	std_hnd = zend_get_std_object_handlers();
 
-	MAKE_STD_ZVAL(member);
-	ZVAL_STRING(member, "doXInclude", 0);
-	doXInclude = std_hnd->read_property(id, member, BP_VAR_IS, NULL TSRMLS_CC);
+	ZVAL_STRING(&member, "doXInclude");
+	doXInclude = std_hnd->read_property(id, &member, BP_VAR_IS, NULL, &rv);
 	if (Z_TYPE_P(doXInclude) != IS_NULL) {
 		convert_to_long(doXInclude);
 		ctxt->xinclude = Z_LVAL_P(doXInclude);
 	}
-	efree(member);
+	zval_ptr_dtor(&member);
 
 	secPrefsValue = intern->securityPrefs;
 
-	/* This whole if block can be removed, when we remove the xsl.security_prefs php.ini option in PHP 6+ */
-	secPrefsIni= INI_INT("xsl.security_prefs");
-	/* if secPrefsIni has the same value as secPrefsValue, all is fine */
-	if (secPrefsIni != secPrefsValue) {
-		if (secPrefsIni != XSL_SECPREF_DEFAULT) {
-			/* if the ini value is not set to the default, throw an E_DEPRECATED warning */
-			php_error_docref(NULL TSRMLS_CC, E_DEPRECATED, "The xsl.security_prefs php.ini option is deprecated; use XsltProcessor->setSecurityPrefs() instead");
-			if (intern->securityPrefsSet == 0) {
-				/* if securityPrefs were not set through the setSecurityPrefs method, take the ini setting */
-				secPrefsValue = secPrefsIni;
-			} else {
-				/* else throw a notice, that the ini setting was not used */
-				php_error_docref(NULL TSRMLS_CC, E_NOTICE, "The xsl.security_prefs php.ini was not used, since the  XsltProcessor->setSecurityPrefs() method was used");
-			}
-		}
-	}
-
 	/* if securityPrefs is set to NONE, we don't have to do any checks, but otherwise... */
 	if (secPrefsValue != XSL_SECPREF_NONE) {
 		secPrefs = xsltNewSecurityPrefs();
@@ -610,7 +578,7 @@ static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStyl
 	}
 
 	if (secPrefsError == 1) {
-		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Can't set libxslt security properties, not doing transformation for security reasons");
+		php_error_docref(NULL, E_WARNING, "Can't set libxslt security properties, not doing transformation for security reasons");
 	} else {
 		newdocp = xsltApplyStylesheetUser(style, doc, (const char**) params,  NULL, f, ctxt);
 	}
@@ -629,7 +597,7 @@ static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStyl
 		intern->node_list = NULL;
 	}
 
-	php_libxml_decrement_doc_ref(intern->doc TSRMLS_CC);
+	php_libxml_decrement_doc_ref(intern->doc);
 	efree(intern->doc);
 	intern->doc = NULL;
 
@@ -646,7 +614,7 @@ static xmlDocPtr php_xsl_apply_stylesheet(zval *id, xsl_object *intern, xsltStyl
 }
 /* }}} */
 
-/* {{{ proto domdocument xsl_xsltprocessor_transform_to_doc(domnode doc);
+/* {{{ proto domdocument xsl_xsltprocessor_transform_to_doc(domnode doc)
 URL: http://www.w3.org/TR/2003/WD-DOM-Level-3-Core-20030226/DOM3-Core.html#
 Since:
 */
@@ -655,25 +623,23 @@ PHP_FUNCTION(xsl_xsltprocessor_transform_to_doc)
 	zval *id, *docp = NULL;
 	xmlDoc *newdocp;
 	xsltStylesheetPtr sheetp;
-	int ret, ret_class_len=0;
-	char *ret_class = NULL;
+	zend_string *ret_class = NULL;
 	xsl_object *intern;
 
 	id = getThis();
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	intern = Z_XSL_P(id);
 	sheetp = (xsltStylesheetPtr) intern->ptr;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "o|s!", &docp, &ret_class, &ret_class_len) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "o|S!", &docp, &ret_class) == FAILURE) {
 		RETURN_FALSE;
 	}
 
-	newdocp = php_xsl_apply_stylesheet(id, intern, sheetp, docp TSRMLS_CC);
+	newdocp = php_xsl_apply_stylesheet(id, intern, sheetp, docp);
 
 	if (newdocp) {
 		if (ret_class) {
-			int found;
-			char *curclass_name;
-			zend_class_entry *curce, **ce;
+			zend_string *curclass_name;
+			zend_class_entry *curce, *ce;
 			php_libxml_node_object *interndoc;
 
 			curce = Z_OBJCE_P(docp);
@@ -682,21 +648,21 @@ PHP_FUNCTION(xsl_xsltprocessor_transform_to_doc)
 				curce = curce->parent;
 			}
 
-			found = zend_lookup_class(ret_class, ret_class_len, &ce TSRMLS_CC);
-			if ((found != SUCCESS) || !instanceof_function(*ce, curce TSRMLS_CC)) {
+			ce = zend_lookup_class(ret_class);
+			if (ce == NULL || !instanceof_function(ce, curce)) {
 				xmlFreeDoc(newdocp);
-				php_error_docref(NULL TSRMLS_CC, E_WARNING,
-					"Expecting class compatible with %s, '%s' given", curclass_name, ret_class);
+				php_error_docref(NULL, E_WARNING,
+					"Expecting class compatible with %s, '%s' given", ZSTR_VAL(curclass_name), ZSTR_VAL(ret_class));
 				RETURN_FALSE;
 			}
 
-			object_init_ex(return_value, *ce);
+			object_init_ex(return_value, ce);
 
-			interndoc = (php_libxml_node_object *)zend_objects_get_address(return_value TSRMLS_CC);
-			php_libxml_increment_doc_ref(interndoc, newdocp TSRMLS_CC);
-			php_libxml_increment_node_ptr(interndoc, (xmlNodePtr)newdocp, (void *)interndoc TSRMLS_CC);
+			interndoc = Z_LIBXML_NODE_P(return_value);
+			php_libxml_increment_doc_ref(interndoc, newdocp);
+			php_libxml_increment_node_ptr(interndoc, (xmlNodePtr)newdocp, (void *)interndoc);
 		} else {
-			DOM_RET_OBJ((xmlNodePtr) newdocp, &ret, NULL);
+			php_dom_create_object((xmlNodePtr) newdocp, return_value, NULL);
 		}
 	} else {
 		RETURN_FALSE;
@@ -705,26 +671,27 @@ PHP_FUNCTION(xsl_xsltprocessor_transform_to_doc)
 }
 /* }}} end xsl_xsltprocessor_transform_to_doc */
 
-/* {{{ proto int xsl_xsltprocessor_transform_to_uri(domdocument doc, string uri);
+/* {{{ proto int xsl_xsltprocessor_transform_to_uri(domdocument doc, string uri)
 */
 PHP_FUNCTION(xsl_xsltprocessor_transform_to_uri)
 {
 	zval *id, *docp = NULL;
 	xmlDoc *newdocp;
 	xsltStylesheetPtr sheetp;
-	int ret, uri_len;
+	int ret;
+	size_t uri_len;
 	char *uri;
 	xsl_object *intern;
 
 	id = getThis();
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	intern = Z_XSL_P(id);
 	sheetp = (xsltStylesheetPtr) intern->ptr;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "op", &docp, &uri, &uri_len) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "op", &docp, &uri, &uri_len) == FAILURE) {
 		RETURN_FALSE;
 	}
 
-	newdocp = php_xsl_apply_stylesheet(id, intern, sheetp, docp TSRMLS_CC);
+	newdocp = php_xsl_apply_stylesheet(id, intern, sheetp, docp);
 
 	ret = -1;
 	if (newdocp) {
@@ -736,7 +703,7 @@ PHP_FUNCTION(xsl_xsltprocessor_transform_to_uri)
 }
 /* }}} end xsl_xsltprocessor_transform_to_uri */
 
-/* {{{ proto string xsl_xsltprocessor_transform_to_xml(domdocument doc);
+/* {{{ proto string xsl_xsltprocessor_transform_to_xml(domdocument doc)
 */
 PHP_FUNCTION(xsl_xsltprocessor_transform_to_xml)
 {
@@ -749,20 +716,20 @@ PHP_FUNCTION(xsl_xsltprocessor_transform_to_xml)
 	xsl_object *intern;
 
 	id = getThis();
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	intern = Z_XSL_P(id);
 	sheetp = (xsltStylesheetPtr) intern->ptr;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "o", &docp) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "o", &docp) == FAILURE) {
 		RETURN_FALSE;
 	}
 
-	newdocp = php_xsl_apply_stylesheet(id, intern, sheetp, docp TSRMLS_CC);
+	newdocp = php_xsl_apply_stylesheet(id, intern, sheetp, docp);
 
 	ret = -1;
 	if (newdocp) {
 		ret = xsltSaveResultToString(&doc_txt_ptr, &doc_txt_len, newdocp, sheetp);
 		if (doc_txt_ptr && doc_txt_len) {
-			RETVAL_STRINGL(doc_txt_ptr, doc_txt_len, 1);
+			RETVAL_STRINGL((char *) doc_txt_ptr, doc_txt_len);
 			xmlFree(doc_txt_ptr);
 		}
 		xmlFreeDoc(newdocp);
@@ -774,49 +741,40 @@ PHP_FUNCTION(xsl_xsltprocessor_transform_to_xml)
 }
 /* }}} end xsl_xsltprocessor_transform_to_xml */
 
-/* {{{ proto bool xsl_xsltprocessor_set_parameter(string namespace, mixed name [, string value]);
+/* {{{ proto bool xsl_xsltprocessor_set_parameter(string namespace, mixed name [, string value])
 */
 PHP_FUNCTION(xsl_xsltprocessor_set_parameter)
 {
 
 	zval *id;
-	zval *array_value, **entry, *new_string;
+	zval *array_value, *entry, new_string;
 	xsl_object *intern;
-	char *string_key, *name, *value, *namespace;
-	ulong idx;
-	int string_key_len, namespace_len, name_len, value_len;
+	char *namespace;
+	size_t namespace_len;
+	zend_string *string_key, *name, *value;
 	DOM_GET_THIS(id);
 
-	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sa", &namespace, &namespace_len, &array_value) == SUCCESS) {
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
-		zend_hash_internal_pointer_reset(Z_ARRVAL_P(array_value));
-
-		while (zend_hash_get_current_data(Z_ARRVAL_P(array_value), (void **)&entry) == SUCCESS) {
-			SEPARATE_ZVAL(entry);
-			convert_to_string_ex(entry);
-
-			if (zend_hash_get_current_key_ex(Z_ARRVAL_P(array_value), &string_key, &string_key_len, &idx, 0, NULL) != HASH_KEY_IS_STRING) {
-				php_error_docref(NULL TSRMLS_CC, E_WARNING, "Invalid parameter array");
+	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "sa", &namespace, &namespace_len, &array_value) == SUCCESS) {
+		intern = Z_XSL_P(id);
+		ZEND_HASH_FOREACH_STR_KEY_VAL(Z_ARRVAL_P(array_value), string_key, entry) {
+			if (string_key == NULL) {
+				php_error_docref(NULL, E_WARNING, "Invalid parameter array");
 				RETURN_FALSE;
 			}
-
-			ALLOC_ZVAL(new_string);
-			Z_ADDREF_PP(entry);
-			COPY_PZVAL_TO_ZVAL(*new_string, *entry);
-
-			zend_hash_update(intern->parameter, string_key, string_key_len, &new_string, sizeof(zval*), NULL);
-			zend_hash_move_forward(Z_ARRVAL_P(array_value));
-		}
+			convert_to_string_ex(entry);
+			if (Z_REFCOUNTED_P(entry)) {
+				Z_ADDREF_P(entry);
+			}
+			zend_hash_update(intern->parameter, string_key, entry);
+		} ZEND_HASH_FOREACH_END();
 		RETURN_TRUE;
+	} else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "sSS", &namespace, &namespace_len, &name, &value) == SUCCESS) {
 
-	} else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "sss", &namespace, &namespace_len, &name, &name_len, &value, &value_len) == SUCCESS) {
+		intern = Z_XSL_P(id);
 
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+		ZVAL_STR_COPY(&new_string, value);
 
-		MAKE_STD_ZVAL(new_string);
-		ZVAL_STRING(new_string, value, 1);
-
-		zend_hash_update(intern->parameter, name, name_len + 1, &new_string, sizeof(zval*), NULL);
+		zend_hash_update(intern->parameter, name, &new_string);
 		RETURN_TRUE;
 	} else {
 		WRONG_PARAM_COUNT;
@@ -825,47 +783,49 @@ PHP_FUNCTION(xsl_xsltprocessor_set_parameter)
 }
 /* }}} end xsl_xsltprocessor_set_parameter */
 
-/* {{{ proto string xsl_xsltprocessor_get_parameter(string namespace, string name);
+/* {{{ proto string xsl_xsltprocessor_get_parameter(string namespace, string name)
 */
 PHP_FUNCTION(xsl_xsltprocessor_get_parameter)
 {
 	zval *id;
-	int name_len = 0, namespace_len = 0;
-	char *name, *namespace;
-	zval **value;
+	char *namespace;
+	size_t namespace_len = 0;
+	zval *value;
+	zend_string *name;
 	xsl_object *intern;
 
 	DOM_GET_THIS(id);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ss", &namespace, &namespace_len, &name, &name_len) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "sS", &namespace, &namespace_len, &name) == FAILURE) {
 		RETURN_FALSE;
 	}
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
-	if ( zend_hash_find(intern->parameter, name, name_len + 1,  (void**) &value) == SUCCESS) {
+	intern = Z_XSL_P(id);
+	if ((value = zend_hash_find(intern->parameter, name)) != NULL) {
 		convert_to_string_ex(value);
-		RETVAL_STRING(Z_STRVAL_PP(value),1);
+		RETURN_STR_COPY(Z_STR_P(value));
 	} else {
 		RETURN_FALSE;
 	}
 }
 /* }}} end xsl_xsltprocessor_get_parameter */
 
-/* {{{ proto bool xsl_xsltprocessor_remove_parameter(string namespace, string name);
+/* {{{ proto bool xsl_xsltprocessor_remove_parameter(string namespace, string name)
 */
 PHP_FUNCTION(xsl_xsltprocessor_remove_parameter)
 {
 	zval *id;
-	int name_len = 0, namespace_len = 0;
-	char *name, *namespace;
+	size_t namespace_len = 0;
+	char *namespace;
+	zend_string *name;
 	xsl_object *intern;
 
 	DOM_GET_THIS(id);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ss", &namespace, &namespace_len, &name, &name_len) == FAILURE) {
+	if (zend_parse_parameters(ZEND_NUM_ARGS(), "sS", &namespace, &namespace_len, &name) == FAILURE) {
 		RETURN_FALSE;
 	}
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
-	if ( zend_hash_del(intern->parameter, name, name_len + 1) == SUCCESS) {
+	intern = Z_XSL_P(id);
+	if (zend_hash_del(intern->parameter, name) == SUCCESS) {
 		RETURN_TRUE;
 	} else {
 		RETURN_FALSE;
@@ -873,44 +833,36 @@ PHP_FUNCTION(xsl_xsltprocessor_remove_parameter)
 }
 /* }}} end xsl_xsltprocessor_remove_parameter */
 
-/* {{{ proto void xsl_xsltprocessor_register_php_functions([mixed $restrict]);
+/* {{{ proto void xsl_xsltprocessor_register_php_functions([mixed $restrict])
 */
 PHP_FUNCTION(xsl_xsltprocessor_register_php_functions)
 {
 	zval *id;
 	xsl_object *intern;
-	zval *array_value, **entry, *new_string;
-	int  name_len = 0;
-	char *name;
+	zval *array_value, *entry, new_string;
+	zend_string *name;
 
 	DOM_GET_THIS(id);
 
-	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "a",  &array_value) == SUCCESS) {
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
-		zend_hash_internal_pointer_reset(Z_ARRVAL_P(array_value));
+	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "a",  &array_value) == SUCCESS) {
+		intern = Z_XSL_P(id);
 
-		while (zend_hash_get_current_data(Z_ARRVAL_P(array_value), (void **)&entry) == SUCCESS) {
-			SEPARATE_ZVAL(entry);
+		ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(array_value), entry) {
 			convert_to_string_ex(entry);
+			ZVAL_LONG(&new_string ,1);
+			zend_hash_update(intern->registered_phpfunctions, Z_STR_P(entry), &new_string);
+		} ZEND_HASH_FOREACH_END();
 
-			MAKE_STD_ZVAL(new_string);
-			ZVAL_LONG(new_string,1);
-
-			zend_hash_update(intern->registered_phpfunctions, Z_STRVAL_PP(entry), Z_STRLEN_PP(entry) + 1, &new_string, sizeof(zval*), NULL);
-			zend_hash_move_forward(Z_ARRVAL_P(array_value));
-		}
 		intern->registerPhpFunctions = 2;
+	} else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "S",  &name) == SUCCESS) {
+		intern = Z_XSL_P(id);
 
-	} else if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "s",  &name, &name_len) == SUCCESS) {
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
-
-		MAKE_STD_ZVAL(new_string);
-		ZVAL_LONG(new_string,1);
-		zend_hash_update(intern->registered_phpfunctions, name, name_len + 1, &new_string, sizeof(zval*), NULL);
+		ZVAL_LONG(&new_string,1);
+		zend_hash_update(intern->registered_phpfunctions, name, &new_string);
 		intern->registerPhpFunctions = 2;
 
 	} else {
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+		intern = Z_XSL_P(id);
 		intern->registerPhpFunctions = 1;
 	}
 
@@ -923,16 +875,16 @@ PHP_FUNCTION(xsl_xsltprocessor_set_profiling)
 	zval *id;
 	xsl_object *intern;
 	char *filename = NULL;
-	int filename_len;
+	size_t filename_len;
 	DOM_GET_THIS(id);
 
-	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "p!", &filename, &filename_len) == SUCCESS) {
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "p!", &filename, &filename_len) == SUCCESS) {
+		intern = Z_XSL_P(id);
 		if (intern->profiling) {
 			efree(intern->profiling);
 		}
 		if (filename != NULL) {
-			intern->profiling = estrndup(filename,filename_len);
+			intern->profiling = estrndup(filename, filename_len);
 		} else {
 			intern->profiling = NULL;
 		}
@@ -948,13 +900,13 @@ PHP_FUNCTION(xsl_xsltprocessor_set_security_prefs)
 {
 	zval *id;
 	xsl_object *intern;
-	long securityPrefs, oldSecurityPrefs;
+	zend_long securityPrefs, oldSecurityPrefs;
 
 	DOM_GET_THIS(id);
- 	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &securityPrefs) == FAILURE) {
+ 	if (zend_parse_parameters(ZEND_NUM_ARGS(), "l", &securityPrefs) == FAILURE) {
 		return;
 	}
-	intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	intern = Z_XSL_P(id);
 	oldSecurityPrefs = intern->securityPrefs;
 	intern->securityPrefs = securityPrefs;
 	/* set this to 1 so that we know, it was set through this method. Can be removed, when we remove the ini setting */
@@ -970,8 +922,8 @@ PHP_FUNCTION(xsl_xsltprocessor_get_security_prefs)
 	xsl_object *intern;
 
 	DOM_GET_THIS(id);
-	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS() TSRMLS_CC, "") == SUCCESS) {
-		intern = (xsl_object *)zend_object_store_get_object(id TSRMLS_CC);
+	if (zend_parse_parameters_ex(ZEND_PARSE_PARAMS_QUIET, ZEND_NUM_ARGS(), "") == SUCCESS) {
+		intern = Z_XSL_P(id);
 		RETURN_LONG(intern->securityPrefs);
 	} else {
 		WRONG_PARAM_COUNT;
@@ -979,9 +931,7 @@ PHP_FUNCTION(xsl_xsltprocessor_get_security_prefs)
 }
 /* }}} end xsl_xsltprocessor_get_security_prefs */
 
-
-
-/* {{{ proto bool xsl_xsltprocessor_has_exslt_support();
+/* {{{ proto bool xsl_xsltprocessor_has_exslt_support()
 */
 PHP_FUNCTION(xsl_xsltprocessor_has_exslt_support)
 {
